/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef PRTHREAD_H_
#define PRTHREAD_H_

#include "prtypes.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef struct PRThread PRThread;

PRThread* PR_GetCurrentThread();

typedef void (*PRThreadPrivateDTOR)(void* priv);

PRStatus PR_NewThreadPrivateIndex(
	PRUintn* newIndex, PRThreadPrivateDTOR destructor);

PRStatus PR_SetThreadPrivate(PRUintn tpdIndex, void* priv);

void* PR_GetThreadPrivate(PRUintn tpdIndex);

#ifdef __cplusplus
}
#endif

#endif
